@@ -481,9 +481,7 @@ class EmailSend(object):
 
 @ezfuc.retry(2)
 def getIP():
-    ip_url = "http://ip.42.pl/raw"
-    ip_res = requests.get(ip_url).text
-    res = requests.get(f"http://elanpy.com:39111/?key=123&self_ip={ip_res}").json()
+    res = requests.get("http://elanpy.com:39111/?key=123").json()
     if res["code"] ==200:
         return res
     elif res["code"] ==300:
